@@ -72,13 +72,13 @@ class Randomer:
             CreditCardSecurityCode: fake.credit_card_security_code,
             CompanyName: fake.company,
             CompanySuffix: fake.company_suffix,
+            Email: lambda: fake.email(),
             FileName: fake.file_name,
             Ipv4: fake.ipv4,
             Ipv6: fake.ipv6,
             MacAddress: fake.mac_address,
             UserAgent: fake.user_agent,
             URI: fake.uri,
-            Email: fake.email,
             Username: fake.user_name,
             FirstName: fake.first_name_male,
             LastName: fake.last_name_male,
@@ -100,6 +100,8 @@ class Randomer:
             ),
             MongoId: DataGenerate.mongo_id,
             Uuid: lambda: str(uuid.uuid4()),
+            Number: lambda: str(rnd.randint(0, 1000000)),
+            Money: lambda: rnd.randint(0, 100000000)/100,
         }
         self.add_types(types)
 
